package Qt::Gui::QGraphicsAnchor;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QGraphicsAnchor
# file     : QtGui/qgraphicsanchorlayout.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QObject/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QGraphicsAnchor

=head1 PUBLIC METHODS

=over

=item   ~QGraphicsAnchor()

=item  void setSizePolicy(QSizePolicy::Policy policy)

=item  void setSpacing(qreal spacing)

=item  QSizePolicy::Policy sizePolicy()

=item  qreal spacing()

=item  void unsetSpacing()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
